pub struct InitializeAccounts<'a> {
pub sender: AccountInfo<'a>,
pub sender_tokens: AccountInfo<'a>,
pub recipient: AccountInfo<'a>,
pub recipient_tokens: AccountInfo<'a>,
pub metadata: AccountInfo<'a>,
pub escrow_tokens: AccountInfo<'a>,
pub mint: AccountInfo<'a>,
pub rent: AccountInfo<'a>,
pub token_program: AccountInfo<'a>,
pub associated_token_program: AccountInfo<'a>,
pub system_program: AccountInfo<'a>,
}Expand description
The account-holding struct for the stream initialization instruction
Fields
sender: AccountInfo<'a>The main wallet address of the initializer.
sender_tokens: AccountInfo<'a>The associated token account address of sender.
recipient: AccountInfo<'a>The main wallet address of the recipient.
recipient_tokens: AccountInfo<'a>The associated token account address of recipient.
(Can be either empty or initialized).
metadata: AccountInfo<'a>The account holding the stream metadata. Expects empty (non-initialized) account.
escrow_tokens: AccountInfo<'a>The escrow account holding the stream funds. Expects empty (non-initialized) account.
mint: AccountInfo<'a>The SPL token mint account
rent: AccountInfo<'a>The Rent Sysvar account
token_program: AccountInfo<'a>The SPL program needed in case an associated account for the new recipient is being created.
associated_token_program: AccountInfo<'a>The Associated Token program needed in case associated account for the new recipient is being created.
system_program: AccountInfo<'a>The Solana system program