Struct streamflow_timelock::state::TransferAccounts[][src]

pub struct TransferAccounts<'a> {
    pub existing_recipient: AccountInfo<'a>,
    pub new_recipient: AccountInfo<'a>,
    pub new_recipient_tokens: AccountInfo<'a>,
    pub metadata: AccountInfo<'a>,
    pub escrow_tokens: AccountInfo<'a>,
    pub mint: AccountInfo<'a>,
    pub rent: AccountInfo<'a>,
    pub token_program: AccountInfo<'a>,
    pub associated_token_program: AccountInfo<'a>,
    pub system_program: AccountInfo<'a>,
}
Accounts needed for updating stream recipient

Fields

existing_recipient: AccountInfo<'a>

Wallet address of the existing recipient

new_recipient: AccountInfo<'a>

New stream beneficiary

new_recipient_tokens: AccountInfo<'a>

New stream beneficiary’s token account. If not initialized, it will be created and existing_recipient is the fee payer

metadata: AccountInfo<'a>

The account holding the stream metadata

escrow_tokens: AccountInfo<'a>

The escrow account holding the stream funds

mint: AccountInfo<'a>

The SPL token mint account

rent: AccountInfo<'a>

Rent account

token_program: AccountInfo<'a>

The SPL program needed in case associated account for the new recipients is being created.

associated_token_program: AccountInfo<'a>

The Associated Token program needed in case associated account for the new recipients is being created.

system_program: AccountInfo<'a>

The Solana system program needed in case associated account for the new recipients is being created.