Function streamflow_timelock::associated_token::initialize_token_stream [−][src]
pub fn initialize_token_stream(
program_id: &Pubkey,
acc: InitializeAccounts<'_>,
ix: StreamInstruction
) -> ProgramResultExpand description
Initialize an SPL token stream
The function shall initialize new accounts to hold the tokens, and the stream’s metadata. Both accounts will be funded to be rent-exempt if necessary. When the stream is finished, these shall be returned to the stream initializer.